# Iron(II,III) oxide, Fe3O4

## Other names

- Ferrous ferric oxide
- Ferroso ferric oxide
- Black iron oxide
- Rust
- Iron(II) diiron(III) oxide
- Iron oxide
- Triiron tetraoxide

## Minerals

- Magnetite
- Lodestone (naturally magnetized magnetite)

## External links

- Iron(II,III) oxide - Wikipedia
- Triiron tetraoxide - WebElements
- Magnetite - Wikipedia
- Lodestone - Wikipedia
- Rust - Wikipedia